@@ -3,7 +3,7 @@ import asyncio
 from ddtrace.vendor.wrapt import ObjectProxy
 from ddtrace.vendor.wrapt import wrap_function_wrapper as _w
 
-from ...compat import CONTEXTVARS_IS_AVAILABLE
+from ...internal.compat import CONTEXTVARS_IS_AVAILABLE
 from ...utils.wrappers import unwrap as _u
 from .wrappers import wrapped_create_task
 from .wrappers import wrapped_create_task_contextvars
