@@ -1,19 +1,23 @@
 import flask
 import werkzeug
-from ddtrace.vendor import debtcollector
+
+from ddtrace import Pin
+from ddtrace import config
 from ddtrace.vendor.wrapt import wrap_function_wrapper as _w
 
-from ddtrace import compat
-from ddtrace import config, Pin
-
-from ...constants import ANALYTICS_SAMPLE_RATE_KEY, SPAN_MEASURED_KEY
+from .. import trace_utils
+from ...constants import ANALYTICS_SAMPLE_RATE_KEY
+from ...constants import SPAN_MEASURED_KEY
 from ...ext import SpanTypes
 from ...internal.logger import get_logger
-from ...propagation.http import HTTPPropagator
+from ...utils.version import parse_version
 from ...utils.wrappers import unwrap as _u
-from .. import trace_utils
-from .helpers import get_current_app, get_current_span, simple_tracer, with_instance_pin
-from .wrappers import wrap_function, wrap_signal
+from .helpers import get_current_app
+from .helpers import simple_tracer
+from .helpers import with_instance_pin
+from .wrappers import wrap_function
+from .wrappers import wrap_signal
+
 
 log = get_logger(__name__)
 
@@ -33,9 +37,6 @@ config._add(
         distributed_tracing_enabled=True,
         template_default_name="<memory>",
         trace_signals=True,
-        # We mark 5xx responses as errors, these codes are additional status codes to mark as errors
-        # DEV: This is so that if a user wants to see `401` or `403` as an error, they can configure that
-        extra_error_codes=set(),
     ),
 )
 
@@ -53,7 +54,7 @@ config._add(
 #      (0, 9, 0) != (0, 9)
 #      (0, 8, 5) <= (0, 9)
 flask_version_str = getattr(flask, "__version__", "0.0.0")
-flask_version = tuple([int(i) for i in flask_version_str.split(".")])
+flask_version = parse_version(flask_version_str)
 
 
 def patch():
@@ -260,12 +261,7 @@ def traced_wsgi_app(pin, wrapped, instance, args, kwargs):
     request = werkzeug.Request(environ)
 
     # Configure distributed tracing
-    if config.flask.get("distributed_tracing_enabled", False):
-        propagator = HTTPPropagator()
-        context = propagator.extract(request.headers)
-        # Only need to activate the new context if something was propagated
-        if context.trace_id:
-            pin.tracer.context_provider.activate(context)
+    trace_utils.activate_distributed_headers(pin.tracer, int_config=config.flask, request_headers=request.headers)
 
     # Default resource is method and path:
     #   GET /
@@ -309,19 +305,6 @@ def traced_wsgi_app(pin, wrapped, instance, args, kwargs):
                     s.resource = u"{} {}".format(request.method, code)
 
                 trace_utils.set_http_meta(s, config.flask, status_code=code, response_headers=headers)
-
-                extra_error_codes = config.flask.get("extra_error_codes")
-                if extra_error_codes:
-                    debtcollector.deprecate(
-                        (
-                            "ddtrace.config.flask['extra_error_codes'] is now deprecated, "
-                            "use ddtrace.config.http_server.error_statuses"
-                        ),
-                        removal_version="0.47.0",
-                    )
-                    if code in extra_error_codes:
-                        s.error = 1
-
                 return func(status_code, headers)
 
             return traced_start_response
@@ -335,7 +318,7 @@ def traced_wsgi_app(pin, wrapped, instance, args, kwargs):
             config.flask,
             method=request.method,
             url=request.base_url,
-            query=compat.to_unicode(request.query_string),
+            query=request.query_string,
             request_headers=request.headers,
         )
 
@@ -432,9 +415,9 @@ def traced_render(wrapped, instance, args, kwargs):
     This method is called for render_template or render_template_string
     """
     pin = Pin._find(wrapped, instance, get_current_app())
-    # DEV: `get_current_span` will verify `pin` is valid and enabled first
-    span = get_current_span(pin)
-    if not span:
+    span = pin.tracer.current_span()
+
+    if not pin.enabled or not span:
         return wrapped(*args, **kwargs)
 
     def _wrap(template, context, app):
@@ -464,8 +447,8 @@ def request_tracer(name):
 
         This wrapper will add identifier tags to the current span from `flask.app.Flask.wsgi_app`.
         """
-        span = get_current_span(pin)
-        if not span:
+        span = pin.tracer.current_span()
+        if not pin.enabled or not span:
             return wrapped(*args, **kwargs)
 
         try:
